# endersgame ![tests](https://github.com/microprediction/endersgame/actions/workflows/tests.yml/badge.svg)

Utilities to help build `Attackers` that detect small departures from martingality in time-series. 

### About
This package is intended to make life simpler for those participating in an ongoing tournament at [CrunchDAO.com](https://www.crunchdao.com), although it hopefully has independent interest. For instance, you might build on `Attacker` or examples herein to help find signal in your model residuals.  

 - Colab [notebooks](https://github.com/microprediction/endersnotebooks) demonstrating `Attacker`.
 - See the README in [attacker.md](https://github.com/microprediction/endersgame/blob/main/endersgame/attackers/attacker.md).  
 - It's also highly recommended to read the [FAQ.md](https://github.com/microprediction/endersgame/blob/main/endersgame/attackers/FAQ.md).


### Install 
Stable:

     pip install endersgame 

Latest:

     pip install git+https://github.com/microprediction/endersgame.git
 
### Contributing

Play the game! You might win some cash or even have ongoing upside. See the  [discord channel](https://discord.gg/td29hK6s) and [CrunchDAO.com](https://www.crunchdao.com). 


